---
title: vaultwarden_ldap_docker
type: docs
---

[![Source Code](https://img.shields.io/badge/gitea-source%20code-blue?logo=gitea&logoColor=white)](https://gitea.rknet.org/ansible/xoxys.vaultwarden_ldap_docker) [![Build Status](https://img.shields.io/drone/build/ansible/xoxys.vaultwarden_ldap_docker?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/ansible/xoxys.vaultwarden_ldap_docker) [![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg)](https://gitea.rknet.org/ansible/xoxys.vaultwarden_ldap_docker/src/branch/master/LICENSE)

Role to setup a [Vaultwarden LDAP](https://gitea.rknet.org/docker/vaultwarden-ldap) Sync Service for [Vaultwarden](https://github.com/dani-garcia/vaultwarden) password safe.

- [Default Variables](#default-variables)
  - [vaultwarden_ldap_bind_dn](#vaultwarden_ldap_bind_dn)
  - [vaultwarden_ldap_bind_password](#vaultwarden_ldap_bind_password)
  - [vaultwarden_ldap_cap_add](#vaultwarden_ldap_cap_add)
  - [vaultwarden_ldap_cap_drop](#vaultwarden_ldap_cap_drop)
  - [vaultwarden_ldap_container_name](#vaultwarden_ldap_container_name)
  - [vaultwarden_ldap_cpu_shares](#vaultwarden_ldap_cpu_shares)
  - [vaultwarden_ldap_host](#vaultwarden_ldap_host)
  - [vaultwarden_ldap_image](#vaultwarden_ldap_image)
  - [vaultwarden_ldap_mail_field](#vaultwarden_ldap_mail_field)
  - [vaultwarden_ldap_memory_limit](#vaultwarden_ldap_memory_limit)
  - [vaultwarden_ldap_memory_reservation](#vaultwarden_ldap_memory_reservation)
  - [vaultwarden_ldap_networks](#vaultwarden_ldap_networks)
  - [vaultwarden_ldap_networks_applied](#vaultwarden_ldap_networks_applied)
  - [vaultwarden_ldap_pids_limit](#vaultwarden_ldap_pids_limit)
  - [vaultwarden_ldap_port](#vaultwarden_ldap_port)
  - [vaultwarden_ldap_restart_policy](#vaultwarden_ldap_restart_policy)
  - [vaultwarden_ldap_scheme](#vaultwarden_ldap_scheme)
  - [vaultwarden_ldap_search_base_dn](#vaultwarden_ldap_search_base_dn)
  - [vaultwarden_ldap_search_filter](#vaultwarden_ldap_search_filter)
  - [vaultwarden_ldap_security_opt](#vaultwarden_ldap_security_opt)
  - [vaultwarden_ldap_service_directory](#vaultwarden_ldap_service_directory)
  - [vaultwarden_ldap_service_stopped](#vaultwarden_ldap_service_stopped)
  - [vaultwarden_ldap_ssl](#vaultwarden_ldap_ssl)
  - [vaultwarden_ldap_sync_interval_seconds](#vaultwarden_ldap_sync_interval_seconds)
  - [vaultwarden_ldap_sync_loop](#vaultwarden_ldap_sync_loop)
  - [vaultwarden_ldap_vaultwarden_admin_token](#vaultwarden_ldap_vaultwarden_admin_token)
  - [vaultwarden_ldap_vaultwarden_url](#vaultwarden_ldap_vaultwarden_url)
  - [vaultwarden_ldap_version](#vaultwarden_ldap_version)
  - [vaultwarden_ldap_volumes](#vaultwarden_ldap_volumes)
- [Dependencies](#dependencies)

---

## Default Variables

### vaultwarden_ldap_bind_dn

#### Default value

```YAML
vaultwarden_ldap_bind_dn: _unset_
```

### vaultwarden_ldap_bind_password

#### Default value

```YAML
vaultwarden_ldap_bind_password: _unset_
```

### vaultwarden_ldap_cap_add

#### Default value

```YAML
vaultwarden_ldap_cap_add: []
```

### vaultwarden_ldap_cap_drop

#### Default value

```YAML
vaultwarden_ldap_cap_drop: []
```

### vaultwarden_ldap_container_name

#### Default value

```YAML
vaultwarden_ldap_container_name: vaultwarden_ldap
```

### vaultwarden_ldap_cpu_shares

#### Default value

```YAML
vaultwarden_ldap_cpu_shares: _unset_
```

#### Example usage

```YAML
vaultwarden_ldap_cpu_shares: '1024'
```

### vaultwarden_ldap_host

#### Default value

```YAML
vaultwarden_ldap_host: _unset_
```

### vaultwarden_ldap_image

#### Default value

```YAML
vaultwarden_ldap_image: thegeeklab/vaultwarden-ldap:{{ vaultwarden_ldap_version }}
```

### vaultwarden_ldap_mail_field

#### Default value

```YAML
vaultwarden_ldap_mail_field: mail
```

### vaultwarden_ldap_memory_limit

#### Default value

```YAML
vaultwarden_ldap_memory_limit: _unset_
```

#### Example usage

```YAML
vaultwarden_ldap_memory_limit: 512m
```

### vaultwarden_ldap_memory_reservation

#### Default value

```YAML
vaultwarden_ldap_memory_reservation: _unset_
```

#### Example usage

```YAML
vaultwarden_ldap_memory_reservation: 256m
```

### vaultwarden_ldap_networks

#### Default value

```YAML
vaultwarden_ldap_networks:
  - name: vaultwarden_default
    external: true
```

#### Example usage

```YAML
vaultwarden_ldap_networks:
  - name: default
    # optional network driver, defaults to 'bride'
    driver: host
```

### vaultwarden_ldap_networks_applied

#### Default value

```YAML
vaultwarden_ldap_networks_applied:
  - vaultwarden_default
```

### vaultwarden_ldap_pids_limit

#### Default value

```YAML
vaultwarden_ldap_pids_limit: _unset_
```

### vaultwarden_ldap_port

#### Default value

```YAML
vaultwarden_ldap_port: _unset_
```

### vaultwarden_ldap_restart_policy

#### Default value

```YAML
vaultwarden_ldap_restart_policy: always
```

### vaultwarden_ldap_scheme

#### Default value

```YAML
vaultwarden_ldap_scheme: _unset_
```

### vaultwarden_ldap_search_base_dn

#### Default value

```YAML
vaultwarden_ldap_search_base_dn: _unset_
```

### vaultwarden_ldap_search_filter

#### Default value

```YAML
vaultwarden_ldap_search_filter: (&(objectclass=*)(uid=*))
```

### vaultwarden_ldap_security_opt

#### Default value

```YAML
vaultwarden_ldap_security_opt: []
```

### vaultwarden_ldap_service_directory

#### Default value

```YAML
vaultwarden_ldap_service_directory: /var/lib/docker/services/vaultwarden_ldap
```

### vaultwarden_ldap_service_stopped

#### Default value

```YAML
vaultwarden_ldap_service_stopped: false
```

### vaultwarden_ldap_ssl

#### Default value

```YAML
vaultwarden_ldap_ssl: true
```

### vaultwarden_ldap_sync_interval_seconds

#### Default value

```YAML
vaultwarden_ldap_sync_interval_seconds: 60
```

### vaultwarden_ldap_sync_loop

#### Default value

```YAML
vaultwarden_ldap_sync_loop: true
```

### vaultwarden_ldap_vaultwarden_admin_token

#### Default value

```YAML
vaultwarden_ldap_vaultwarden_admin_token: abc123
```

### vaultwarden_ldap_vaultwarden_url

#### Default value

```YAML
vaultwarden_ldap_vaultwarden_url: vaultwarden.example.com
```

### vaultwarden_ldap_version

#### Default value

```YAML
vaultwarden_ldap_version: latest
```

### vaultwarden_ldap_volumes

> Define required docker volumes.

#### Default value

```YAML
vaultwarden_ldap_volumes: []
```

#### Example usage

```YAML
vaultwarden_ldap_volumes:
  # Instead of the name you could specify a path on the container host system,
  # but you also have to enable bind mount for this volume
  - name: data
    # target location inside the container
    dest: /app/data
    # enable bind mount, if false volume will be configured as named volume
    # keep in mind you MUST set bind in any case
    bind: True
```



## Dependencies

None.
